GAET
====

Gene-based assembly evaluation tool - evaluate a single assembly or
compare two assemblies using their annotations.

Getting Started
---------------

::

    pip install [--user] gaet

    gaet assembly.gff
    gaet --reference reference.gff assembly.gff

Gaet is written in python 3. If you would prefer, there is a `precompiled
version of gaet`_ which runs on Linux systems.

.. _precompiled version of gaet: https://s3-us-west-1.amazonaws.com/gaet/releases/latest.tar.xz

Documentation
-------------

See `gaet(1)`_ for a description of how to run gaet. See `gaet-format(5)`_
for a description of the output metrics generated by gaet.

.. _gaet(1): https://gitlab.com/michaelbarton/gaet/blob/master/doc/src/gaet.1.md
.. _gaet-format(5): https://gitlab.com/michaelbarton/gaet/blob/master/doc/src/gaet-format.5.md

Running the tests
-----------------

Gaet has both unit tests and feature tests. The unit tests check individual
python functions within the code. The feature tests are run against the
compiled version of gaet and ensure the program works as a whole.

::

    make test
    make feature

Upon a successful pull request onto the master branch, where all tests
pass, a new version of gaet will be released to pypi, and a new precompiled
version released to S3.

Built With
----------

-  `funcy <https://pypi.python.org/pypi/funcy>`__ - functional
   programming for python
-  `gffutils <https://pypi.python.org/pypi/gffutils>`__ - Utilities for
   accessing GFF data
-  `pyfaidx <https://pypi.python.org/pypi/pyfaidx>`__ - Accessing
   substrings of FASTA data
-  `ruamel.yaml <https://pypi.python.org/pypi/ruamel.yaml>`__ - actively
   maintained YAML parsing for python

Authors
-------

-  `Michael Barton <http://michaelbarton.me.uk>`__

License
-------

This project is licensed under the BSD License - see the
`LICENSE.txt <LICENSE.txt>`__ file for details.

See also
--------

-  `QUAST <http://quast.sourceforge.net/>`__- check the completeness of
   an assembly or compare with a reference using size metrics such
   nga50.

-  `checkm <http://ecogenomics.github.io/CheckM/>`__ - checks the
   completeness of an assembly using the expectation of certain
   essential genes.
